@@ -13,18 +13,25 @@ pub const PASSTHROUGH_DATETIME: Opt = 1 << 7;
 pub const APPEND_NEWLINE: Opt = 1 << 8;
 pub const PASSTHROUGH_DATACLASS: Opt = 1 << 9;
 pub const SERIALIZE_PYDANTIC: Opt = 1 << 10;
+pub const PASSTHROUGH_BIG_INT: Opt = 1 << 11;
+pub const PASSTHROUGH_TUPLE: Opt = 1 << 12;
 
-pub const NOT_PASSTHROUGH: Opt =
-    !(PASSTHROUGH_DATETIME | PASSTHROUGH_DATACLASS | PASSTHROUGH_SUBCLASS);
+pub const NOT_PASSTHROUGH: Opt = !(PASSTHROUGH_BIG_INT
+    | PASSTHROUGH_DATACLASS
+    | PASSTHROUGH_DATETIME
+    | PASSTHROUGH_SUBCLASS
+    | PASSTHROUGH_TUPLE);
 
 pub const MAX_PACKB_OPT: i32 = (APPEND_NEWLINE
     | INDENT_2
     | NAIVE_UTC
     | NON_STR_KEYS
     | OMIT_MICROSECONDS
+    | PASSTHROUGH_BIG_INT
     | PASSTHROUGH_DATETIME
     | PASSTHROUGH_DATACLASS
     | PASSTHROUGH_SUBCLASS
+    | PASSTHROUGH_TUPLE
     | SERIALIZE_NUMPY
     | SERIALIZE_PYDANTIC
     | UTC_Z) as i32;
