@@ -22,7 +22,7 @@ impl<'p> Serialize for IntSerializer {
         S: Serializer,
     {
         let val = ffi!(PyLong_AsLongLong(self.ptr));
-        if unlikely!(val == -1) && !ffi!(PyErr_Occurred()).is_null() {
+        if unlikely!(val == -1 && !ffi!(PyErr_Occurred()).is_null()) {
             return UIntSerializer::new(self.ptr).serialize(serializer);
         }
         serializer.serialize_i64(val)
@@ -48,7 +48,7 @@ impl<'p> Serialize for UIntSerializer {
     {
         ffi!(PyErr_Clear());
         let val = ffi!(PyLong_AsUnsignedLongLong(self.ptr));
-        if unlikely!(val == u64::MAX) && !ffi!(PyErr_Occurred()).is_null() {
+        if unlikely!(val == u64::MAX && !ffi!(PyErr_Occurred()).is_null()) {
             err!("Integer exceeds 64-bit range")
         }
         serializer.serialize_u64(val)
